import { Host, h } from "@stencil/core";
import { watchBlockNumber } from "@wagmi/core";
import { ethers } from "ethers";
import state from "../../stores/wallet";
import { handleError } from "../../utils/errors";
export class NKDropMintCrossmintButton {
    constructor() {
        this.handleWindowEvent = (e) => {
            const { data: { type }, } = e;
            const loadingEvents = [
                'payment:preparation.succeeded',
                'payment:process.started',
            ];
            const successEvents = ['payment:process.succeeded'];
            const failedEvents = [
                'payment:rejected',
                'payment:preparation.failed',
                'quote:status.invalidated',
            ];
            if (loadingEvents.includes(type)) {
                this.loading = true;
                this.isMinting = true;
                this.mintSuccess = false;
            }
            if (successEvents.includes(type)) {
                this.dialogTitle = this.successTitle;
                this.dialogMessage = this.successMessage;
                this.dialogOpen = true;
                this.loading = false;
                this.isMinting = false;
                this.mintSuccess = true;
            }
            if (failedEvents.includes(type)) {
                this.dialogTitle = 'Error';
                this.dialogMessage = 'Payment failed';
                this.dialogOpen = true;
                this.loading = false;
                this.isMinting = false;
                this.mintSuccess = false;
            }
        };
        this.projectId = undefined;
        this.collectionId = undefined;
        this.mintSuccess = false;
        this.isMinting = false;
        this.successTitle = 'Success';
        this.successMessage = 'Successfully minted an NFT';
        this.successLinkText = 'here';
        this.successLink = '';
        this.disabled = true;
        this.loading = true;
        this.mintTo = null;
        this.saleActive = undefined;
        this.presaleActive = undefined;
        this.isOpen = false;
        this.dialogOpen = false;
        this.mintConfig = {
            type: 'erc-721',
            quantity: '1',
            totalPrice: '0',
        };
    }
    componentDidLoad() {
        this.crossmintUpdate();
    }
    componentDidUpdate() {
        this.crossmintUpdate();
    }
    componentWillLoad() {
        var _a;
        this.disconnect = watchBlockNumber({ listen: true, chainId: (_a = state.chain) === null || _a === void 0 ? void 0 : _a.id }, async () => {
            var _a, _b;
            const address = (_b = (_a = state.walletClient) === null || _a === void 0 ? void 0 : _a.account) === null || _b === void 0 ? void 0 : _b.address;
            const [saleActive, presaleActive, price] = await Promise.all([
                state.diamond.apps.drop.saleActive(),
                state.diamond.apps.drop.presaleActive(),
                state.diamond.apps.drop.price(),
            ]);
            this.mintTo = address;
            this.saleActive = saleActive;
            this.presaleActive = presaleActive;
            if (this.presaleActive) {
                try {
                    // check that wallet is connected
                    if (!address) {
                        throw new Error('Wallet not connected');
                    }
                    const { allowed, proof } = await state.diamond.verify(address);
                    this.mintConfig = Object.assign(Object.assign({}, this.mintConfig), { allowed,
                        proof });
                }
                catch (err) {
                    console.log(err);
                    this.dialogTitle = 'Error';
                    this.dialogMessage = handleError(err);
                    this.dialogOpen = true;
                }
            }
            this.mintConfig = Object.assign(Object.assign({}, this.mintConfig), { totalPrice: ethers.utils.formatEther(price) });
            this.loading = this.isMinting;
            // sale not active then disable widget
            this.disabled = !(this.saleActive || this.presaleActive);
        });
        if (typeof window !== 'undefined') {
            window.addEventListener('message', this.handleWindowEvent);
        }
    }
    disconnectedCallback() {
        this.disconnect();
        if (typeof window !== 'undefined') {
            window.removeEventListener('message', this.handleWindowEvent);
        }
    }
    crossmintUpdate() {
        this.crossmintButton.setAttribute('mintConfig', JSON.stringify(this.mintConfig, null, 2));
        const shadowRoot = this.crossmintButton.shadowRoot;
        if (shadowRoot) {
            const img = shadowRoot.querySelector('img');
            if (img) {
                img.style.display = 'none';
            }
        }
    }
    async openModal() {
        this.loading = true;
        try {
            this.isOpen = true;
        }
        catch (e) {
            this.loading = false;
            this.isOpen = false;
            this.dialogTitle = 'Error';
            this.dialogMessage = e.message;
            this.dialogOpen = true;
        }
    }
    render() {
        return (h(Host, null, h("script", { src: "https://unpkg.com/@crossmint/client-sdk-vanilla-ui@1.0.1-alpha.4/lib/index.global.js" }), h("div", { part: "crossmint-btn-container", class: "mdc-touch-target-wrapper" }, h("crossmint-pay-button", { exportparts: "button, contentParagraph", ref: (el) => (this.crossmintButton = el), class: "crossmint-btn", disabled: this.loading || this.disabled, projectId: this.projectId, collectionId: this.collectionId, mintTo: this.mintTo })), h("nk-dialog", { open: this.dialogOpen, dialogTitle: this.dialogTitle }, this.dialogMessage, this.mintSuccess && !!this.successLink && (h("span", null, ' ', h("a", { href: this.successLink, target: "_blank", rel: "noreferrer", style: { color: 'rgba(0,0,0,0.6)' } }, this.successLinkText))))));
    }
    static get is() { return "nk-drop-mint-crossmint-button"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nk-drop-mint-crossmint-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nk-drop-mint-crossmint-button.css"]
        };
    }
    static get properties() {
        return {
            "projectId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Crossmint Project Id"
                },
                "attribute": "project-id",
                "reflect": false
            },
            "collectionId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Crossmint Collection Id"
                },
                "attribute": "collection-id",
                "reflect": false
            },
            "successTitle": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Title on the success modal"
                },
                "attribute": "success-title",
                "reflect": false,
                "defaultValue": "'Success'"
            },
            "successMessage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Body message on the success modal"
                },
                "attribute": "success-message",
                "reflect": false,
                "defaultValue": "'Successfully minted an NFT'"
            },
            "successLinkText": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Link text on the success modal"
                },
                "attribute": "success-link-text",
                "reflect": false,
                "defaultValue": "'here'"
            },
            "successLink": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Link on the success modal"
                },
                "attribute": "success-link",
                "reflect": false,
                "defaultValue": "''"
            }
        };
    }
    static get states() {
        return {
            "mintSuccess": {},
            "isMinting": {},
            "disabled": {},
            "loading": {},
            "mintTo": {},
            "saleActive": {},
            "presaleActive": {},
            "isOpen": {},
            "dialogOpen": {},
            "mintConfig": {}
        };
    }
    static get methods() {
        return {
            "openModal": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=nk-drop-mint-crossmint-button.js.map
